# -*- coding: utf-8 -*-
from __future__ import division
from __future__ import print_function

# from builtins import object


# class TestIntegration_ExampleScripts(object):
#     def test_basic(self):
#         pass
